@@ -3,9 +3,29 @@ import os
 from formatConvert.wav_pcm import pcm2wav,wav2pcm
 import  numpy as np
 import math
+from moviepy.editor import *
 
 
 
+def get_wav_from_mp4(mp4file):
+    """
+    Parameters
+    ----------
+    mp4file
+
+    Returns
+    -------
+
+    """
+    suffix = os.path.splitext(mp4file)[-1]
+    if suffix != '.mp4':
+        raise TypeError('wrong format! not mp4 file!' + str(suffix))
+    video = VideoFileClip(mp4file)
+    audio = video.audio
+    newFileName = mp4file[:-4] + '.wav'
+    audio.write_audiofile(newFileName)
+    return newFileName
+
 def get_rms(records):
     '''
     Parameters
@@ -21,15 +41,19 @@ def isSlience(Filename =None):
     """
     Parameters
     ----------
-    Filename 支持 wav 和 pcm
+    Filename 支持 wav 和 pcm 和MP4
 
     Returns
     -------
 
     """
+    suffix = os.path.splitext(Filename)[-1]
+    if suffix == '.mp4':
+        Filename = get_wav_from_mp4(Filename)
     with open(wav2pcm(Filename), 'rb') as ref:
         indata = ref.read()
     ins = np.frombuffer(indata, dtype=np.int16)
+    print(ins)
     dBrmsValue = 20*math.log(get_rms(ins)/32767)
     return dBrmsValue
     pass
@@ -37,7 +61,7 @@ def isSlience(Filename =None):
 
 def audioFormat(wavFileName=None):
     """
-    wavFileName：输入文件 wav，mp4待支持
+    wavFileName：输入文件 wav，mp4
     Returns
     -------
     refChannel:通道数
@@ -46,8 +70,10 @@ def audioFormat(wavFileName=None):
     refframeCount：样点数
     """
     suffix = os.path.splitext(wavFileName)[-1]
-    if suffix != '.wav':
-        raise TypeError('wrong format! not wav file!' + str(suffix))
+    if suffix != '.wav' or suffix != '.mp4':
+        raise TypeError('wrong format! not wav/mp4 file!' + str(suffix))
+    if suffix == '.mp4':
+        wavFileName = get_wav_from_mp4(wavFileName)
     wavf = wave.open(wavFileName, 'rb')
     refChannel,refsamWidth,refsamplerate,refframeCount = wavf.getnchannels(),wavf.getsampwidth(),wavf.getframerate(),wavf.getnframes()
     return refChannel,refsamWidth,refsamplerate,refframeCount
