@@ -5,7 +5,7 @@ import wave
 
 sys.path.append('../')
 from ctypes import *
-from commFunction import emxArray_real_T,get_data_of_ctypes_
+from commFunction import emxArray_real_T,get_data_of_ctypes_,write_ctypes_data_2_file_,get_none_data_of_ctypes_
 import  ctypes
 import numpy as np
 
@@ -28,17 +28,8 @@ def match_sig(refFile=None,testFile=None,outFile=None,audioType=1):
     refstruct, refsamplerate,reflen = get_data_of_ctypes_(refFile)
     teststruct, testsamplerate,testlen = get_data_of_ctypes_(testFile)
     outlen = max(reflen,testlen)
-    data =  np.array([0.0 for _ in range(outlen)])
-    data = data.astype(np.float64)
-
-    outStruct = emxArray_real_T()
-    #outStruct = create_string_buffer(20)
-    outStruct.pdata =  (c_double * outlen)(*data)
-    outStruct.psize = (c_int * 1)(*[outlen])
-    outStruct.allocSize = outlen
-    outStruct.NumDimensions = 1
-    outStruct.canFreeData = 1
 
+    outStruct = get_none_data_of_ctypes_(outlen)
     if refsamplerate != testsamplerate :
         raise TypeError('Different format of ref and test files!')
     mydll = ctypes.windll.LoadLibrary(sys.prefix + '/matchsig.dll')
@@ -50,26 +41,15 @@ def match_sig(refFile=None,testFile=None,outFile=None,audioType=1):
         return None
     else:
         if outFile is not None:
-            outf = wave.open(outFile,'wb')
-            outf.setnchannels(1)
-            outf.setsampwidth(2)
-            outf.setframerate(refsamplerate)
-            # 将wav_data转换为二进制数据写入文件
-            outlist=[]
-            for a in range(outStruct.psize[0]):
-                outlist.append(int(outStruct.pdata[a]))
-            outarray = np.array(outlist)
-            outarray = outarray.astype(np.int16)
-            outf.writeframes(bytes(outarray))
-            outf.close()
+            write_ctypes_data_2_file_(outFile,outStruct,refsamplerate)
         return delay.value
 
 
 
 
 if __name__ == '__main__':
-    ref = r'C:\Users\vcloud_avl\Documents\我的POPO\speech_cn_minus_6.wav'
-    test = r'C:\Users\vcloud_avl\Documents\我的POPO\cleDstFile_minus_6.wav'
+    ref = r'C:\Users\vcloud_avl\Documents\我的POPO\src.wav'
+    test = r'C:\Users\vcloud_avl\Documents\我的POPO\test.wav'
     print(match_sig(refFile=ref, testFile=test, outFile='outfile.wav'))
 
     pass
\ No newline at end of file
