@@ -3,8 +3,7 @@ import sys
 sys.path.append('../')
 import ctypes
 from ctypes import *
-from SNR_ESTIMATION.structFormat import emxArray_real_T,get_data_of_ctypes_
-
+from commFunction import emxArray_real_T,get_data_of_ctypes_
 
 # void SNR_estimation(const emxArray_real_T *ref, const emxArray_real_T *sig,
 #                     double fs, double *SNR, double *err)
